History
=======

Desmod development began in early 2016 as an internal project at SanDisk
Corporation (now Western Digital) out of a desire to improve the pace of
model development for architectural exploration and performance
estimation of solid state storage systems. Using Python and SimPy for
rapid model iteration proved to be a great improvement over SystemC
based strategies.

However, although SimPy is a solid foundation for discrete event
simulation, building a complete model demanded solutions for other
problems such as configuration, command line interface, model
organization, monitoring, logging, capturing results, and more. Desmod
was written to fill those gaps.

Desmod was released as Free Software under the terms of the MIT License
in July, 2016.

.. include:: ../CHANGELOG.rst
